# Changelog

## [2.0.0](https://github.com/Smeds/multiqc_cgs/compare/v1.0.0...v2.0.0) (2026-03-26)


### ⚠ BREAKING CHANGES

* update supported python versions
* migrate to pyproject.toml and release-please v4

### Features

* migrate to pyproject.toml and release-please v4 ([438bc50](https://github.com/Smeds/multiqc_cgs/commit/438bc500cd77930d2fc67e19bd4920eff76cf7ac))
* update supported python versions ([1ef2d42](https://github.com/Smeds/multiqc_cgs/commit/1ef2d42a5f792a5c1c5613e3d1864f029da83ebd))

## 1.0.0 (2025-01-30)


### ⚠ BREAKING CHANGES

* add compatibility to readme

### Bug Fixes

* remove utils ([206b342](https://github.com/Smeds/multiqc_cgs/commit/206b342313a680fc2f6064209c72702a7f234b19))
* remove utils ([debc462](https://github.com/Smeds/multiqc_cgs/commit/debc4624504250d74d3984f21cdd9faae474d83b))
* setting version will not overwrite the config entry for multiqc_cgs ([3f3cd13](https://github.com/Smeds/multiqc_cgs/commit/3f3cd13a5a861d4724a7d787d244b2004a412298))


### Documentation

* add compatibility to readme ([a634b03](https://github.com/Smeds/multiqc_cgs/commit/a634b03cbb07f7634ab33da8e517dd5b4083ba56))
* missed change name of column name in comment ([a21487b](https://github.com/Smeds/multiqc_cgs/commit/a21487b909f02bee11ac520fe1790b708ec3949a))
* update to match new naming of modules ([a3d50bc](https://github.com/Smeds/multiqc_cgs/commit/a3d50bcaa17be23293f5ad5eeaa04da5207f7b91))


### Miscellaneous Chores

* release 1.0.0 ([e2a0d65](https://github.com/Smeds/multiqc_cgs/commit/e2a0d656522074f591823bfbb79b0c33aef57df6))
